@@ -5,11 +5,11 @@ from cdk_toolkit import cicd
 
 
 class CDKCodePipelineStack(Stack): 
-    def __init__(self, scope: Construct, construct_id: str, codecommit_repository_name: str, codecommit_repository_branch: str, codebuild_action_name: str, codebuild_role: str, codepipeline_name: str,   **kwargs) -> None:
+    def __init__(self, scope: Construct, construct_id: str, codecommit_repository_name: str, codecommit_repository_branch: str, codebuild_action_name: str, codebuild_role: str, codepipeline_name: str, codecommit_initial_commit_dir: str,  **kwargs) -> None:
         super().__init__(scope, construct_id, **kwargs)
 
-        # Create CodeCommit Repository
-        codecommit_repository = cicd.createCodeCommitRepository(self, codecommit_repository_name)
+        # Create CodeCommit Repository 
+        codecommit_repository = cicd.createCodeCommitRepository(self, codecommit_repository_name, initial_commit_dir=codecommit_initial_commit_dir, initial_commit_branch="main")
 
         # Create CodeCommit Artifact
         codecommit_artifact = cicd.createCodePipelineArtifact()
